==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Nastavení Media Player Daemon</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Serverová adresa Media Player Daemon</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Přípojka</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Číslo přípojky MPD naslouchá</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Časové omezení pro spojení (sekund)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Počet sekund předtím, než je spojení ukončeno</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Nastavení Media Player Daemon</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Serverová adresa Media Player Daemon</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Přípojka</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Číslo přípojky MPD naslouchá</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Časové omezení pro spojení (sekund)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Počet sekund předtím, než je spojení ukončeno</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
</context>
</TS>
